@@ -2,6 +2,7 @@
 import json
 import os
 import sys
+
 from appdirs import user_config_dir
 
 APP_NAME = "convopus"
@@ -11,10 +12,11 @@ config = {
     "CONTAINER": ".ogg",
     "KEEP": True,
     "VBR": 'on',
+    "RECURSIVE": False,
+    "MULTI_THREADING": True,
     "COMMONTYPES": ('.flac', '.mp3', '.wav', '.m4a',
                     '.aac', '.webm', '.mp4', '.avi', '.mkv')
 }
-
 conf_path = user_config_dir(APP_NAME, APP_AUTHOR)
 CONF_FILE = 'config.json'
 conf_full_path = os.path.join(conf_path, CONF_FILE)
@@ -31,7 +33,7 @@ def read_config():
     '''Reads configuration file.'''
     if not os.path.isfile(conf_full_path):
         generate_config()
-    with open(conf_full_path, 'r', encoding="utf_8") as config_file:
+    with open(conf_full_path, 'r', encoding="utf-8") as config_file:
         config_read = json.load(config_file)
         return config_read
 
@@ -39,6 +41,11 @@ def read_config():
 def print_config():
     '''Prints config location and it's content.'''
     print(conf_full_path)
-    with open(conf_full_path, 'r', encoding="utf_8") as config_file:
+    with open(conf_full_path, 'r', encoding="utf-8") as config_file:
         print(config_file.read())
-    sys.exit()
+        sys.exit()
+
+
+if __name__ == "__main__":
+    generate_config()
+    print_config()
